@@ -8,6 +8,7 @@ import errno
 import logging
 import nbformat
 import importlib
+import signal
 
 try:
     from urlparse import urlparse
@@ -31,7 +32,6 @@ from tornado.log import enable_pretty_logging
 from notebook.notebookapp import random_ports
 from ._version import __version__
 from .services.sessions.sessionmanager import SessionManager
-from .services.activity.manager import ActivityManager
 from .services.kernels.manager import SeedingMappingKernelManager
 
 # Only present for generating help documentation
@@ -346,7 +346,7 @@ class KernelGatewayApp(JupyterApp):
 
     def init_configurables(self):
         """Initializes all configurable objects including a kernel manager, kernel
-        spec manager, session manager, activity manager, and personality.
+        spec manager, session manager, and personality.
 
         Any kernel pool configured by the personality will be its responsibility
         to shut down.
@@ -374,12 +374,6 @@ class KernelGatewayApp(JupyterApp):
             **kwargs
         )
 
-        self.activity_manager = ActivityManager(
-            parent=self,
-            log=self.log,
-            kernel_manager=self.kernel_manager
-        )
-
         self.session_manager = SessionManager(
             log=self.log,
             kernel_manager=self.kernel_manager
@@ -414,7 +408,6 @@ class KernelGatewayApp(JupyterApp):
 
         self.web_app = web.Application(
             handlers=handlers,
-            activity_manager=self.activity_manager,
             kernel_manager=self.kernel_manager,
             session_manager=self.session_manager,
             contents_manager=self.contents_manager,
@@ -505,9 +498,10 @@ class KernelGatewayApp(JupyterApp):
         self.log.info('Jupyter Kernel Gateway at http{}://{}:{}'.format(
             's' if self.keyfile else '', self.ip, self.port
         ))
-
         self.io_loop = ioloop.IOLoop.current()
 
+        signal.signal(signal.SIGTERM, self._signal_stop)
+
         try:
             self.io_loop.start()
         except KeyboardInterrupt:
@@ -528,5 +522,8 @@ class KernelGatewayApp(JupyterApp):
         """Stop all kernels in the pool."""
         self.personality.shutdown()
 
+    def _signal_stop(self, sig, frame):
+        self.log.info("Received signal to terminate.")
+        self.io_loop.stop()
 
 launch_instance = KernelGatewayApp.launch_instance
